@@ -444,6 +444,12 @@ class RedisRoot:
                     new_redis_model = update_redis_model_from_redis_fields(existing_redis_model, redis_fields, redis_root)
                 else:
                     new_redis_model = create_redis_model_from_redis_fields(redis_fields, redis_root)
+
+                for model in redis_root.registered_models:
+                    print()
+                    print(model)
+                    print(model.__model_data__['fields'])
+
                 return new_redis_model
             
             def django_fields_to_redis_fields(django_model, redis_root):
@@ -461,6 +467,7 @@ class RedisRoot:
 
             def create_redis_model_from_redis_fields(redis_fields, redis_root):
                 new_redis_model = type(django_model.__name__, (RedisModel,), redis_fields)
+                print(new_redis_model, new_redis_model.__class__.__name__)
                 redis_root.register_models([new_redis_model])
                 return new_redis_model
 
@@ -529,9 +536,10 @@ class RedisRoot:
                             redis_field_param_name = 'model'
                             if value is not None:
                                 value = value.model
-                                value = get_or_create_redis_model_from_django_model(value, redis_root)
                                 if value is not None:
-                                    allowed_redis_params[redis_field_param_name] = value
+                                    value = get_or_create_redis_model_from_django_model(value, redis_root)
+                                    if value is not None:
+                                        allowed_redis_params[redis_field_param_name] = value
                         else:
                             allowed_redis_params[redis_field_param_name] = value
                 return allowed_redis_params
@@ -547,6 +555,8 @@ class RedisRoot:
                 redis_root.registered_models = new_registered_models
                 return new_redis_model
 
+
+
             cache_func(
                 django_model,
                 self,
